<?php

namespace Drupal\smallads\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for configuring this module.
 */
class Config extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'smallads_config_form';
  }

  /**
   * {@inheritdoc}
   *
   * @todo compose emails for expiry
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('smallads.settings');
    $form['default_expiry'] = [
      '#title' => $this->t('Default expiry date'),
      '#description' => $this->t('Default value of the small ad expiry form widget'),
      '#type' => 'select',
      '#options' => [
        // '' => t('Permanent'),the date widget can't handle empty''.
        '+1 week' => $this->t('1 week'),
        '+1 month' => $this->t('1 month'),
        '+3 months' => $this->t('@count months', ['@count' => 3]),
        '+6 months' => $this->t('@count months', ['@count' => 6]),
        '+1 year' => $this->t('1 year'),
      ],
      '#default_value' => $config->get('default_expiry'),
    ];
    $fieldManager = \Drupal::service('entity_field.manager');
    $options = [];
    foreach ($fieldManager->getFieldMapByFieldType('geofield') as $entity_type_id => $field_info) {
      if (in_array($entity_type_id, ['user', 'smallad'])) {
        $field_storage_definitions = $fieldManager->getFieldStorageDefinitions($entity_type_id);
        foreach ($field_info as $field_name => $info) {
          $key = $entity_type_id . ':' . $field_name;
          $label = \Drupal::entityTypeManager()->getDefinition($entity_type_id)->getLabel() . ' - ' .
            $field_storage_definitions[$field_name]->getName();
          $options[$key] = $label;
        }
      }
    }
    $form['geo_field'] = [
      '#title' => $this->t('Coordinates field instance'),
      '#description' => $this->t('Either on the user or the smallad'),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $config->get('geo_field'),
      '#empty_value' => $this->t('- None -'),
      '#weight' => 10,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = $this->configFactory->getEditable('smallads.settings');

    $config
      ->set('default_expiry', $values['default_expiry'])
      ->set('geo_field', $values['geo_field'])
      ->save();

    parent::submitForm($form, $form_state);
    \Drupal::service('router.builder')->rebuild();

  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['smallads.settings'];
  }

}
